@@ -170,16 +170,16 @@ class ML():
                 }},
 
         'LinearSVM'  : {
-            'estimator' : LinearSVC(penalty='l2', dual=False, random_state=123456),
+            'estimator' : LinearSVC(penalty='l2', dual=True, random_state=123456),
             'parameters': {
                 'GSCV'  : { 'loss': ['hinge', 'squared_hinge'],
                             'tol': [1e-7, 1e-6, 1e-5, 1e-4, 1e-3, 1e-2 ],
                             'C': np.power(10, np.linspace(-1.7, 1.7, 20)),
-                            'max_iter':[8e6, 1.5e7]},
+                            'max_iter':[int(8e6), int(1.5e7)]},
                 'RSCV'  : {}
                 }},
         'LinearSVMl1'   : {
-            'estimator' : LinearSVC(penalty='l1', max_iter=1e6, random_state=123456),
+            'estimator' : LinearSVC(penalty='l1', max_iter=int(1e6), random_state=123456),
             'parameters': {
                 'GSCV'  : { 'dual' : [False, True],
                             'loss': ['squared_hinge'],
@@ -264,7 +264,7 @@ class ML():
                 }},
 
         'SGD'           : {
-            'estimator' : SGDClassifier(max_iter =1e5, learning_rate='optimal', n_jobs=2, random_state=123456),
+            'estimator' : SGDClassifier(max_iter = int(1e5), learning_rate='optimal', n_jobs=2, random_state=123456),
             'parameters': {
                 'GSCV'  : [{ 'penalty' : ['l2','elasticnet'],
                              'loss': ['hinge','log','modified_huber','squared_hinge','perceptron' ],
@@ -370,25 +370,25 @@ class ML():
                                              np.power(10, np.arange(-3,3,0.3))
                                            ],
                               'l1_ratios': [ [0.005, 0.05, 0.1, 0.3, 0.5, 0.7, 0.9], ],
-                              'max_iter' : [ 4e4 ],
+                              'max_iter' : [ int(4e4) ],
                               'cv'       : [ 10  ],
                               'solver'   : [ 'saga']},
                           ],
                 'RSCV'  : [ { 'penalty'  : [ 'l1'],
                               'Cs'       : [ np.power(10, np.arange(-2,4,0.3)) ],
                               'l1_ratios': [ None ],
-                              'max_iter' : [ 6e4 ],
+                              'max_iter' : [ int(6e4) ],
                               'cv'       : [ 10 ],
                               'solver'   : [ 'liblinear', 'saga']},
                             { 'penalty'  : [ 'l2'],
                               'l1_ratios': [ None ],
-                              'max_iter' : [ 6e4 ],
+                              'max_iter' : [ int(6e4) ],
                               'cv'       : [ 10   ],
                               'Cs'       : [ np.power(10, np.arange(-2,4,0.3)) ],
                               'solver'   : [ 'lbfgs', 'sag']},
                             { 'penalty'  : [ 'elasticnet'],
                               'Cs'       : [ np.power(10, np.arange(-2,4,0.3)) ],
-                              'max_iter' : [ 6e4 ],
+                              'max_iter' : [ int(6e4) ],
                               'cv'       : [ 10 ],
                               'solver'   : ['saga']},
                           ],
