@@ -11,7 +11,7 @@
 
 
 import traceback
-import os
+import os,sys
 import time
 from .MLPipeline import Pipeline
 from .MLLogging import Logger
@@ -52,11 +52,14 @@ def Commands():
         Log.NIF('**%s|%-13s: %s'%(str(i).zfill(2), k, str(getattr(args, k))) )
     Log.NIF(59 * '*')
 
+    return_code = 0
     try:
         Pipeline(args, Log).Pipe()
         Log.CIF('Success!!!')
     except Exception:
         traceback.print_exc()
+        return_code = 1
     finally:
         Log.CIF('You can check your progress in log file.')
+        exit(return_code)
 
